//
//  Copyright 2011 Canonical Ltd.
//	
//  This program is free software: you can redistribute it and/or modify it
//  under the terms of the GNU Affero General Public License version 3,
//  as published by the Free Software Foundation.
//	
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranties of
//  MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
//  PURPOSE.  See the GNU Affero General Public License for more details.
//
//  You should have received a copy of the GNU Affero General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#import "U1Asset.h"
#import "U1AutoUploadOperation.h"
#import "U1DataRepository.h"
#import "U1FileNode.h"
#import "U1FilesClient.h"

@interface U1AutoUploadOperation ()
@property (getter=isExecuting) BOOL executing;
@property (getter=isFinished) BOOL finished;
- (void)finishExecuting;
- (void)beginUpload;
@end

@implementation U1AutoUploadOperation

@synthesize executing, finished, dataProvider, u1asset, folder, filename, contentType, priority;

- (BOOL)isConcurrent;
{
	return YES;
}

- (void)finishExecuting;
{
	[self willChangeValueForKey:@"isExecuting"];
	[self willChangeValueForKey:@"isFinished"];
	self.finished = YES;
	self.executing = NO;
	[self didChangeValueForKey:@"isFinished"];
	[self didChangeValueForKey:@"isExecuting"];
}

- (void)start;
{
	[self willChangeValueForKey:@"isExecuting"];
	self.executing = YES;
	[self didChangeValueForKey:@"isExecuting"];
	
	[self beginUpload];
}

- (void)dealloc
{
	[dataProvider release];
	[u1asset release];
	[folder release];
	[filename release];
	[contentType release];
    [super dealloc];
}

- (void)beginUpload;
{
	dispatch_async(dispatch_get_main_queue(), ^(void) {
		[[U1FilesClient sharedFilesClient] uploadContentDataProvider:dataProvider toFolder:self.folder withResourceName:self.filename withContentType:self.contentType withPriority:self.priority progressBlock:^(long long bytesUploaded, long long totalBytes) {
		
		} completionBlock:^(U1FileNode *fileNode, NSError *error) {
			if (error)
			{
				NSLog(@"auto-upload failed: %@", error);
			}			

			dispatch_async(dispatch_get_main_queue(), ^(void) {
				
				self.u1asset.generation = self.u1asset.fileNode.generation;
				[[U1DataRepository sharedDataRepository] save:NULL];
				[self finishExecuting];
			});
		}];
	});
}

@end
