//
//  Copyright 2011 Canonical Ltd.
//	
//  This program is free software: you can redistribute it and/or modify it
//  under the terms of the GNU Affero General Public License version 3,
//  as published by the Free Software Foundation.
//	
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranties of
//  MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
//  PURPOSE.  See the GNU Affero General Public License for more details.
//
//  You should have received a copy of the GNU Affero General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#import "U1ReportingInputStream.h"


@interface U1ReportingInputStream ()
@property (retain) NSInputStream *targetStream;
@end


@implementation U1ReportingInputStream
{
	NSUInteger contentLength;
	NSUInteger readSoFar;
}

@synthesize progressBlock;
@synthesize targetStream;

+ (NSInputStream *)inputStreamWithData:(NSData *)data;
{
	return [[[self alloc] initWithData:data] autorelease];
}

- (id)initWithData:(NSData *)theData;
{
	targetStream = [[NSInputStream alloc] initWithData:theData];
	contentLength = [theData length];
	return self;
}

- (void)dealloc;
{
	[progressBlock release];
	[targetStream release];
	[super dealloc];
}

- (NSInteger)read:(uint8_t *)buffer maxLength:(NSUInteger)len;
{
	NSInteger read = [self.targetStream read:buffer maxLength:len];
	readSoFar += read;
	if (self.progressBlock)
		self.progressBlock(readSoFar, contentLength); 
	return read;
}

- (BOOL)getBuffer:(uint8_t **)buffer length:(NSUInteger *)len;
{
	return NO;
}

- (BOOL)hasBytesAvailable;
{
	return [self.targetStream hasBytesAvailable];
}

- (id)forwardingTargetForSelector:(SEL)aSelector;
{
	return self.targetStream;
}

- (BOOL)respondsToSelector:(SEL)aSelector;
{
	return [self.targetStream respondsToSelector:aSelector];
}

- (BOOL)isKindOfClass:(Class)aClass;
{
	return [self.targetStream isKindOfClass:aClass];
}

@end
