//
//  Copyright 2011 Canonical Ltd.
//	
//  This program is free software: you can redistribute it and/or modify it
//  under the terms of the GNU Affero General Public License version 3,
//  as published by the Free Software Foundation.
//	
//  This program is distributed in the hope that it will be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranties of
//  MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
//  PURPOSE.  See the GNU Affero General Public License for more details.
//
//  You should have received a copy of the GNU Affero General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#import "U1UTIMapper.h"

@interface U1UTIMapper ()
@property (retain) NSDictionary *mappings;
@end

static U1UTIMapper *sharedU1UTIMapper = nil;

@implementation U1UTIMapper

@synthesize mappings;

+ (U1UTIMapper *)sharedU1UTIMapper;
{
	if (sharedU1UTIMapper == nil)
	{
		sharedU1UTIMapper = [[self alloc] init];
	}
	return sharedU1UTIMapper;
}

- (id)init;
{
	self = [super init];
	if (self == nil)
		return nil;
	self.mappings = [NSDictionary dictionaryWithContentsOfFile:
					 [[NSBundle mainBundle] pathForResource:@"uti-mappings" ofType:@"plist"]];
	return self;
}

- (void)dealloc
{
	[mappings release];
    [super dealloc];
}

- (NSString *)humanReadableTypeForUTI:(NSString *)uti;
{
	return [[self.mappings objectForKey:uti] objectForKey:@"type"];
}

- (NSString *)extensionForUTI:(NSString *)uti;
{
	return [[self.mappings objectForKey:uti] objectForKey:@"extension"];
}

- (NSString *)MIMETypeForUTI:(NSString *)uti;
{
	return [[self.mappings objectForKey:uti] objectForKey:@"mimetype"];
}

@end
